/*
 * This is the header file for the MD5 message-digest algorithm.
 * The algorithm is due to Ron Rivest.  This code was
 * written by Colin Plumb in 1993, no copyright is claimed.
 * This code is in the public domain; do with it what you wish.
 *
 * Equivalent code is available from RSA Data Security, Inc.
 * This code has been tested against that, and is equivalent,
 * except that you don't need to include two pages of legalese
 * with every copy.
 *
 * To compute the message digest of a chunk of bytes, declare an
 * MD5Context structure, pass it to MD5Init, call MD5Update as
 * needed on buffers full of bytes, and then call MD5Final, which
 * will fill a supplied 16-byte array with the digest.
 *
 * Changed so as no longer to depend on Colin Plumb's `usual.h'
 * header definitions
 *  - Ian Jackson <ijackson@nyx.cs.du.edu>.
 * Still in the public domain.
 *
 * Some minor additions by Stef Walter <stef@memberwebs.com>
 */

#ifdef __cplusplus
extern "C" {
#endif

#ifndef MD5_H
#define MD5_H

#define MD5_LEN 16
#define md5byte unsigned char

typedef struct md5_ctx
{
    unsigned int buf[4];
    unsigned int bytes[2];
    unsigned int in[16];
}
md5_ctx_t;

void md5_init(md5_ctx_t* context);
void md5_update(md5_ctx_t* context, const void* buf, unsigned len);
void md5_final(unsigned char digest[MD5_LEN], md5_ctx_t* context);
void md5_string(unsigned char digest[MD5_LEN], const char* str);
int md5_strcmp(unsigned char digest[MD5_LEN], const char* str);

#ifdef __cplusplus
}
#endif

#endif /* !MD5_H */
