/*
 * Copyright (c) 2008, Stefan Walter
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *     * Redistributions of source code must retain the above
 *       copyright notice, this list of conditions and the
 *       following disclaimer.
 *     * Redistributions in binary form must reproduce the
 *       above copyright notice, this list of conditions and
 *       the following disclaimer in the documentation and/or
 *       other materials provided with the distribution.
 *     * The names of contributors to this software may not be
 *       used to endorse or promote products derived from this
 *       software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 *
 *
 * CONTRIBUTORS
 *  Stef Walter <stef@memberwebs.com>
 *
 */

#include "config.h"

#include "run-tests.h"

#include "common/buffer.h"

#include "daemon/ntlmssp.h"

static const char* NTLMSSP[] = {
    "TlRMTVNTUAABAAAAB4IIogAAAAAAAAAAAAAAAAAAAAAFASgKAAAADw==",
    "TlRMTVNTUAADAAAAGAAYAJYAAAAYABgArgAAACQAJABIAAAAEAAQAGwAAAAaABoAfAAAAAAAAADGAAAABYIAAgUBKAoAAAAPdwB3AHcALgB0AGQAYwBoAHIAaQBzAHQAaQBhAG4ALgBjAGEAZQB2AHIAaQBlAGwAaQBuAFAAQQBSAEEATABMAEUATABTAC0AWABQAEIAKU/H2r63aYbzjYFHFbkDb09WCkepLi72AnOw5Xxxdxfovxz7IF6cZPei5JD5gEcr",
    NULL
};

/*
 * Each test looks like (on one line):
 *     void unit_test_xxxxx (CuTest* cu)
 *
 * Each setup looks like (on one line):
 *     void unit_setup_xxxxx (void)
 *
 * Each teardown looks like (on one line):
 *     void unit_teardown_xxxxx (void)
 *
 * Tests be run in the order specified here.
 */

void unit_test_ntlmssp_decode (CuTest *cu)
{
    ntlmssp_info_rec ntlmssp;
    ha_buffer_t buffer;
    const char** h;
    size_t len;
    void* data;
    unsigned int flags = 0;
    int r;

    for (h = NTLMSSP; *h; ++h) {
    	ha_bufinit (&buffer);

    	len = 0;
        data = ha_bufdec64(&buffer, *h, &len);
        CuAssert(cu, "base64 decoding failed", data != NULL);
        CuAssert(cu, "base64 decoding resulted in 0 length", len > 0);

        r = ntlmssp_decode_msg(&ntlmssp, data, len, &flags);
        CuAssertIntEquals(cu, 0, r);

        ha_buffree (&buffer);
    }
}

/* -----------------------------------------------------------------------------
 * Code being tested
 */

#include "common/buffer.c"
#include "daemon/ntlmssp.c"
