/*
 * Copyright (c) 2008, Stefan Walter
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *     * Redistributions of source code must retain the above
 *       copyright notice, this list of conditions and the
 *       following disclaimer.
 *     * Redistributions in binary form must reproduce the
 *       above copyright notice, this list of conditions and
 *       the following disclaimer in the documentation and/or
 *       other materials provided with the distribution.
 *     * The names of contributors to this software may not be
 *       used to endorse or promote products derived from this
 *       software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 *
 *
 * CONTRIBUTORS
 *  Stef Walter <stef@memberwebs.com>
 *
 */

#include "config.h"

#include "run-tests.h"

#include "common/stringx.h"

static const char* PARSES[] = {
	"one 'twenty \"two\"' 'three",
        " one 'twenty \"two\"' 'three'    \n",
        "one 	twenty\\ \\\"two\\\"  	\nthree  ",
        "   one\n \"twenty \\\"two\\\"\" three",
        NULL
};

/*
 * Each test looks like (on one line):
 *     void unit_test_xxxxx (CuTest* cu)
 *
 * Each setup looks like (on one line):
 *     void unit_setup_xxxxx (void)
 *
 * Each teardown looks like (on one line):
 *     void unit_teardown_xxxxx (void)
 *
 * Tests be run in the order specified here.
 */

void unit_test_str_array_general (CuTest *cu)
{
	char** array;

	array = str_array_create ("one", "two", "three", NULL);
	CuAssertPtrNotNull (cu, array);
	CuAssertStrEquals (cu, "one", array[0]);
	CuAssertStrEquals (cu, "two", array[1]);
	CuAssertStrEquals (cu, "three", array[2]);

	array = str_array_append (array, "four");
	CuAssertStrEquals (cu, "four", array[3]);

	array = str_array_appendn (array, "five and fifty", 4);
	CuAssertStrEquals (cu, "five", array[4]);

	str_array_free (array);
}

void unit_test_str_array_parse (CuTest *cu)
{
	char** array;
	int i;

	for (i = 0; PARSES[i]; ++i) {
		array = str_array_parse_quoted (PARSES[i]);
		// fprintf (stderr, "%d --- %s", i, PARSES[i]);
		CuAssertPtrNotNull (cu, array);
		CuAssertIntEquals (cu, 3, str_array_length (array));
		CuAssertStrEquals (cu, "one", array[0]);
		CuAssertStrEquals (cu, "twenty \"two\"", array[1]);
		CuAssertStrEquals (cu, "three", array[2]);
	}
}

/* -----------------------------------------------------------------------------
 * Code being tested
 */

#include "common/stringx.c"
